@@ -184,6 +184,7 @@ class JobDescription:
     internal_hostname_named: Optional[str] = None
     restart_policy: JobRestartPolicy = JobRestartPolicy.NEVER
     life_span: Optional[float] = None
+    schedule_timeout: Optional[float] = None
     preset_name: Optional[str] = None
     preemptible_node: bool = False
     privileged: bool = False
@@ -552,8 +553,10 @@ class Jobs(metaclass=NoPublicConstructor):
             if e.headers and "X-Error" in e.headers:
                 log.error(f"Error during port-forwarding: {e.headers['X-Error']}")
             log.exception("Unhandled exception during port-forwarding")
+            writer.close()
         except Exception:
             log.exception("Unhandled exception during port-forwarding")
+            writer.close()
 
     async def _port_reader(
         self, ws: aiohttp.ClientWebSocketResponse, writer: asyncio.StreamWriter
@@ -891,6 +894,7 @@ def _job_description_from_api(res: Dict[str, Any], parse: Parser) -> JobDescript
         uri=URL(res["uri"]),
         restart_policy=restart_policy,
         life_span=life_span,
+        schedule_timeout=res.get("schedule_timeout", None),
         preset_name=res.get("preset_name"),
     )
 
